/*******************************************************************************
 * \file IntPrioDef.h
 * \brief Interrupt configuration file.
 * \version 0.1.0.0
 * \date 07-Apr-2021
 * \copyright Copyright (C) Infineon Technologies AG 2019
 *
 * Use of this file is subject to the terms of use agreed between (i) you or
 * the company in which ordinary course of business you are acting and (ii)
 * Infineon Technologies AG or its licensees. If and as long as no such terms
 * of use are agreed, use of this file is subject to following:
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer, must
 * be included in all copies of the Software, in whole or in part, and all
 * derivative works of the Software, unless such copies or derivative works are
 * solely in the form of machine-executable object code generated by a source
 * language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 ******************************************************************************/

#ifndef INTPRIODEF_H
#define INTPRIODEF_H 1
/******************************************************************************/
#define SRE_ON    (1u << 10u)  /* Service Request Enable */
#define SRE_OFF   (0u << 10u)  /* Service Request non-enabled */
#define CLRR      (1u << 25u)  /* Clear SRR */
#define SETR      (1u << 26u)  /* Set SRR and SWS */
#define IOVCLR    (1u << 28u)  /* Interrupt Trigger Overflow Clear Bit */
#define SWSCLR    (1u << 30u)  /* SW Sticky Clear Bit */
#define TOS_CPU0  (0u << 11u)
#define TOS_DMA   (1u << 11u)
#define TOS_CPU1  (2u << 11u)
#define TOS_CPU2  (3u << 11u)
#define TOS_CPU3  (4u << 11u)
#define TOS_CPU4  (5u << 11u)
#define TOS_CPU5  (6u << 11u)

/******************************************************************************/

#define VECTAB0 0
#define VECTAB1 1
#define VECTAB2 2
#define VECTAB3 3
#define VECTAB4 4
#define VECTAB5 5

#define CPU0_SERVICE 0u
#define DMA_SERVICE  1u
#define CPU1_SERVICE 2u
#define CPU2_SERVICE 3u
#define CPU3_SERVICE 4u
#define CPU4_SERVICE 5u
#define CPU5_SERVICE 6u
#define PDMA_SERVICE 7u

/* Enter the DMA Channel in order */
#define SRPN_DMA_CH_QSPI1_TX    3
#define SRPN_DMA_CH_QSPI1_RX    4

/* Enter the interrupt table in order */

/* Enter the interrupt table in order for CPU0 */
#define SPRN_CPU0_STM0_STMIR0  1
#define SPRN_CPU0_STM0_STMIR1  0
#define SRPN_CPU0_DMA_CH3      3
#define SRPN_CPU0_DMA_CH4      4
#define SRPN_CPU0_QSPI1_U      5
#define SRPN_CPU0_QSPI1_PT     6
#define SRPN_CPU0_QSPI1_TX     7
#define SRPN_CPU0_QSPI1_RX     8
#define SRPN_CPU0_QSPI1_ERR    9


/* Enter the interrupt table in order for CPU1 */


/******************************************************************************/

#endif /* INTPRIODEF_H */

/*************************************************************************
 Development history of the file
 28Oct19 Initial version

*************************************************************************/
