# SPI_Master_DMA_1_TC364_SK

## Toolchain

AURIX Development Studio (V1.6.0)

## Overview

Simple example to demonstrate a Master SPI configuration where the data movement is done with DMA channels (One for Master Transmit and the other Master Receive).

This project is using a reduced set of the iLLD's.

However the configuration of the QSP1, DMA channels 3 and 4 along with the ports are implemented in code as bare metal.

## Hardware

AURIX Starter Kit (TC364DP AA)

### Description

In this code example, QSPI1 is configured as a master SPI. DMA channel 3 is used to transmit the data packet whereas DMA channel 4 is used to receive the data packet (SPI is use in full duplex mode. In this example the MTSR pin it externally connected to the MRST pin as there is not a real SPI slave device). The code directly accesses the registers for the QSPI and DMA. It doesn't use the iLLD's for these peripherals.

### Clocks

* The system clock (PLL) is configured to run at 300MHz.
* The system peripheral bus is configured to run at 100MHz.
* The QSPI clock is fSOURCE2 configured to run at 200MHz.

### Peripherals

* QSPI1
* DMA

### Details to the Demo
The QSPI is operated in "Short Data Continuous Mode" When using this mode the transfer requires that you write two BACON entries. The first write is to begin the data exchange and ensure the LAST=0 at the start of the data transfer (it can also be used to remove any delay between the data on the bus). The other BACON write is used to close the data transfer before the last data value is written (i.e LAST=1). In this example the DMA transmit interrupt is used to to write the last BACON and data value to complete the data exchange. Therefore the DMA transfer count for the TX is always one less than the receive DMA transfer count.

The SPI data exchange is initialed be writing the BACON word to the BACONENTRY register. This will cause the Tx DMA to send its data until the transmit count is zero. The receive dma is also triggered by data being received from the QSPI. When both DMA counts go to zero interrupts are raised for the CPU.

<img src="images/ShortDataContinuousMode.png" width="600" >

The demo assumes you have data buffers of "8-bits" in size that are aligned on a word boundaries. Where you have the choice to transfer the data using the DMA with either 8-bit, 16-bit or 32-bit transfers. The QSPI and DMA will handle theis choice from the below define "QQSPI_DL" define. additionally the QSPI will handle the Endianess of the bytes in both directions.

~~~markdown
#define DMA_CH_SIZE_INT8  0
#define DMA_CH_SIZE_INT16 1
#define DMA_CH_SIZE_INT32 2

/*change this for the size of the DMA transfer, the endianess is handled by the QSPI */
#define QSPI_DL DMA_CH_SIZE_INT8
~~~

### Scope plots

Example of one data exchange on the Master QSPI

* (channel 1, white) is P11.6 QSPI1 Master Clock Output
* (channel 2, tan) is P11.9 QSPI1 Master Transmit Output
* (channel 3, red) is P11.3 QSPI1 Master Receive Input B
* (channel 4, brown) is P10.5 QSPI1 Slave Select Output 9 (ECON1)

#define QSPI_DL DMA_CH_SIZE_INT8

<img src="images/txlen64.png" width="600" >
<img src="images/SpiTransfer64bytes.png" width="600" >

#define QSPI_DL DMA_CH_SIZE_INT32

<img src="images/txlen16.png" width="600" >
<img src="images/SpiTransfer16words.png" width="600" >
