/******************************************************************************
 * \file qspi_private.h
 * \copyright Copyright (C) Infineon Technologies AG 2019
 *
 * Use of this file is subject to the terms of use agreed between (i) you or
 * the company in which ordinary course of business you are acting and (ii)
 * Infineon Technologies AG or its licensees. If and as long as no such terms
 * of use are agreed, use of this file is subject to following:
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer, must
 * be included in all copies of the Software, in whole or in part, and all
 * derivative works of the Software, unless such copies or derivative works are
 * solely in the form of machine-executable object code generated by a source
 * language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/
#ifndef QSPI_PRIVATE_H
#define QSPI_PRIVATE_H 1

/***#### GLOBALCON ####***/

/** \brief Status Injection
 * Selects if the status register content injection into the RxFIFO is enabled
 * or disabled. The status injections, if enabled, is performed after each
 * data block, depending on the BACON.DL and BYTE setting.
 */
typedef enum
{
  qspi_globalcon_si_Disabled,    /**< \brief  */
	qspi_globalcon_si_Enabled,     /**< \brief  */
} qspi_globalcon_si;

/** \brief Loop-Back Control
 * Selects if the transmit output is internally connected to the receive input
 * for test purposes
 */
typedef enum
{
	qspi_globalcon_lb_Inactive,  /**< \brief  */
  qspi_globalcon_lb_Active,    /**< \brief  */
} qspi_globalcon_lb;

/** \brief Time-Out Value for the Expect Phase
 * expressed in TQSPI units
 */
typedef enum
{
	qspi_globalcon_expect_64,       /**< \brief */
	qspi_globalcon_expect_128,      /**< \brief */
	qspi_globalcon_expect_256,      /**< \brief */
	qspi_globalcon_expect_512,      /**< \brief */
	qspi_globalcon_expect_1024,     /**< \brief */
	qspi_globalcon_expect_2048,     /**< \brief */
	qspi_globalcon_expect_4096,     /**< \brief */
	qspi_globalcon_expect_8192,     /**< \brief */
	qspi_globalcon_expect_16384,    /**< \brief */
	qspi_globalcon_expect_32768,    /**< \brief */
	qspi_globalcon_expect_65536,    /**< \brief */
	qspi_globalcon_expect_131072,   /**< \brief */
	qspi_globalcon_expect_262144,   /**< \brief */
	qspi_globalcon_expect_524288,   /**< \brief */
	qspi_globalcon_expect_1048576,  /**< \brief */
	qspi_globalcon_expect_2097152,  /**< \brief */
} qspi_globalcon_expect;


/** \brief Delayed Mode for SLSO0
 * Switches the delayed mode for external multiplexer enabling on and off
 */
typedef enum
{
	qspi_globalcon_del0_Off,  /**< \brief Delayed mode off */
	qspi_globalcon_del0_On,   /**< \brief  Delayed mode on */
} qspi_globalcon_del0;

/** \brief Strobe Delay for SLSO0 in Delayed Mode
 * Defines the length of the SLSO0 delay in TQ time units as defined for
 * channel z (TQ units) selected by the current BACON.CS,
 * if GLOBALCON.DEL0 = 1.
 */
typedef enum
{
	qspi_globalcon_strobe_NotUsed,       /**< \brief */
	qspi_globalcon_strobe_1=0,       /**< \brief */
	qspi_globalcon_strobe_2,       /**< \brief */
	qspi_globalcon_strobe_3,       /**< \brief */
	qspi_globalcon_strobe_4,       /**< \brief */
	qspi_globalcon_strobe_5,       /**< \brief */
	qspi_globalcon_strobe_6,       /**< \brief */
	qspi_globalcon_strobe_7,       /**< \brief */
	qspi_globalcon_strobe_8,       /**< \brief */
	qspi_globalcon_strobe_9,       /**< \brief */
	qspi_globalcon_strobe_10,       /**< \brief */
	qspi_globalcon_strobe_11,       /**< \brief */
	qspi_globalcon_strobe_12,       /**< \brief */
	qspi_globalcon_strobe_13,       /**< \brief */
	qspi_globalcon_strobe_14,       /**< \brief */
	qspi_globalcon_strobe_15,       /**< \brief */
	qspi_globalcon_strobe_16,       /**< \brief */
	qspi_globalcon_strobe_17,       /**< \brief */
	qspi_globalcon_strobe_18,       /**< \brief */
	qspi_globalcon_strobe_19,       /**< \brief */
	qspi_globalcon_strobe_20,       /**< \brief */
	qspi_globalcon_strobe_21,       /**< \brief */
	qspi_globalcon_strobe_22,       /**< \brief */
	qspi_globalcon_strobe_23,       /**< \brief */
	qspi_globalcon_strobe_24,       /**< \brief */
	qspi_globalcon_strobe_25,       /**< \brief */
	qspi_globalcon_strobe_26,       /**< \brief */
	qspi_globalcon_strobe_27,       /**< \brief */
	qspi_globalcon_strobe_28,       /**< \brief */
	qspi_globalcon_strobe_29,       /**< \brief */
	qspi_globalcon_strobe_30,       /**< \brief */
	qspi_globalcon_strobe_31,       /**< \brief */
	qspi_globalcon_strobe_32,       /**< \brief */
} qspi_globalcon_strobe;

/** \brief Stop on RxFIFO Full
 * If this bit is set, the data fetching out of the TxFIFO by the shift
 * register stops when the RxFIFO is full, in order to prevent RxFIFO
 * overflow. Master mode only.
 */
typedef enum
{
	qspi_globalcon_srf_disabled,          /**< \brief  */
	qspi_globalcon_srf_StopOnRxFiFoFull,  /**< \brief  */
} qspi_globalcon_srf;

/** \brief Slave Transmit Idle State Polarity
 * This bit determines the logic level of the Slave Mode transmit signal MRST
 * when the QSPI slave select input signals are inactive (PISEL.SLSIS ≠ 000B)
 */
typedef enum
{
	qspi_globalcon_stip_NotUsed,        /**< \brief  */
	qspi_globalcon_stip_OutputZero=0,  /**< \brief  */
  qspi_globalcon_stip_OutputOne,     /**< \brief  */
} qspi_globalcon_stip;

/** \brief Enable Bit
 * Used to request transition between PAUSE and RUN mode per software.
 * Cleared by hardware automatically at leaving the following states:
 * disabled, suspend and sleep.
 * In order to determine if the requested state has actually been reached,
 * the STATUS.PHASE bit field should be polled.
 */
typedef enum
{
	qspi_globalcon_en_PAUSE,  /**< \brief PAUSE requested */
  qspi_globalcon_en_RUN     /**< \brief RUN requested */
} qspi_globalcon_en;

/** \brief Master Slave Mode
 * Selects if the module operates in master or slave mode. This bit field must
 * be configured before the first write to the TXFIFO.
 */
typedef enum
{
	qspi_globalcon_ms_MasterTransmitReceive,      /**< \brief Master Transmit and Receive */
  qspi_globalcon_ms_SlaveTransmitReceive = 2,   /**< \brief Slave Transmit and Receive */
} qspi_globalcon_ms;

/** \brief Automatic Reset Enable
 * Enables the reset of the GLOBALCON.EN on baud rate and spike error in
 * slave mode.
 */
typedef enum
{
	qspi_globalcon__aren_AutomaticResetDisabled,  /**< \brief  */
  qspi_globalcon_aren_AutomaticResetEnabled,   /**< \brief  */
} qspi_globalcon_aren;

#if (TC3XX==1)
/** \brief Clock Select
 * Definition in
 */
typedef enum
{
  qspi_globalcon_NoClock,           /**< \brief  */
  qspi_globalcon_PeripheralClock,   /**< \brief  */
} qspi_globalcon_clksel;
#endif


/** \brief Bits for resetting sub-modules per software
 * Write to this bit field triggers a reset operation. The reset operation is
 * not a single cycle operation, but takes several clock cycles, not more than
 * the least common multiple of CCUCON0.SPBDIV and CCUCON0.BAUD2DIV
 * (the configured division ratios, not the content of the bit fields)
 */

#if (TC3XX==1)
typedef enum
{
  qspi_globalcon_resets_default=0,
  qspi_globalcon_resets_NoResetTriggered=0,       /**< \brief  */
  qspi_globalcon_resets_StateMachineFifoReset=1,  /**< \brief  */
  qspi_globalcon_resets_StateMachineReset=2,      /**< \brief  */
  qspi_globalcon_resets_ModuleReset=3,            /**< \brief  */
} qspi_globalcon_resets;
#else
typedef enum
{
  qspi_globalcon_resets_default=0,
  qspi_globalcon_resets_NoResetTriggered=0,       /**< \brief  */
  qspi_globalcon_resets_StateMachineFifoReset=7,  /**< \brief  */
  qspi_globalcon_resets_ModuleReset=15,           /**< \brief  */
} qspi_globalcon_resets;
#endif


/***#### GLOBALCON1 ####***/

/** \brief Error Enable Bits
 * Bits for enabling interrupt on all available error types
 */
typedef enum
{
  qspi_globalcon1_errorens_AllErrorsDisabled=0x000,            /**< \brief All errors disabled */
  qspi_globalcon1_errorens_ParityError=0x001,                  /**< \brief Parity Error (PAREEN) */
  qspi_globalcon1_errorens_UnexpectedConfigurationError=0x002, /**< \brief Unexpected Configuration Error */
  qspi_globalcon1_errorens_BaudRateError=0x004,                /**< \brief Baud Rate Error (slave mode) BEN */
  qspi_globalcon1_errorens_TXFIFO_overflow=0x008,              /**< \brief TXFIFO overflow (software error) */
  qspi_globalcon1_errorens_TXFIFO_underflow=0x010,             /**< \brief TXFIFO underflow (slave mode) TEN */
  qspi_globalcon1_errorens_RXFIFO_overflow=0x020,              /**< \brief RXFIFO overflow REN */
  qspi_globalcon1_errorens_RXFIFO_underflow=040,               /**< \brief RXFIFO underflow (software error) */
  qspi_globalcon1_errorens_EXPECT_timeout=0x080,               /**< \brief EXPECT timeout */
  qspi_globalcon1_errorens_SLSI_misplacedInactivationEnable=0x100, /**< \brief SLSI misplaced inactivation enable */
  qspi_globalcon1_errorens_AllErrorsEnabled=0x1FF,             /**< \brief All errors enabled */
} qspi_globalcon1_errorens;

/** \brief Tx Interrupt Event Enable
 * Enables the Tx interrupt
 */
typedef enum
{
	qspi_globalcon1_txen_InterruptDisabled,  /**< \brief  */
	qspi_globalcon1_txen_InterruptEnabled,   /**< \brief  */
} qspi_globalcon1_txen;

/** \brief Rx Interrupt Event Enable
 * Enables the Rx interrupt
 */
typedef enum
{
	qspi_globalcon1_rxen_InterruptDisabled,  /**< \brief  */
	qspi_globalcon1_rxen_InterruptEnabled,   /**< \brief  */
} qspi_globalcon1_rxen;

/** \brief Interrupt on PT1 Event Enable
 * Enables the PT interrupt on an PT1 event, as selected by the PT1 bit field
 */
typedef enum
{
	qspi_globalcon1_pt1en_InterruptDisabled,  /**< \brief  */
	qspi_globalcon1_pt1en_InterruptEnabled,   /**< \brief  */
} qspi_globalcon1_pt1en;

/** \brief Interrupt on PT2 Event Enable
 * Enables the PT interrupt on an PT2 event, as selected by the PT2 bit field
 */
typedef enum
{
	qspi_globalcon1_pt2en_InterruptDisabled,  /**< \brief  */
	qspi_globalcon1_pt2en_InterruptEnabled,   /**< \brief  */
} qspi_globalcon1_pt2en;

/** \brief Interrupt on USR Event Enable
 * Enables the USR interrupt on an USR event, as selected by the PT1 bit field
 */
typedef enum
{
	qspi_globalcon1_usren_InterruptDisabled,  /**< \brief  */
	qspi_globalcon1_usren_InterruptEnabled,   /**< \brief  */
} qspi_globalcon1_usren;

/** \brief Transmit FIFO Interrupt Threshold
 * If the TXFIFO filling level is equal or less than this threshold, than
 * each move of data or configuration from the TXFIFO triggers a transmit
 * interrupt. Reset value of the level is 01B.
 */
typedef enum
{
	qspi_globalcon1_txfifoint_Level1,  /**< \brief  */
	qspi_globalcon1_txfifoint_Level2,  /**< \brief  */
	qspi_globalcon1_txfifoint_Level3,  /**< \brief  */
	qspi_globalcon1_txfifoint_Level4,  /**< \brief  */
} qspi_globalcon1_txfifoint;

/** \brief Receive FIFO Interrupt Threshold
 * If the RXFIFO filling level is equal or greater than this threshold, than
 * each move of data or status (if enabled) into the RXFIFO triggers a receive
 * interrupt. Reset value of the level is 01B.
 */
typedef enum
{
	qspi_globalcon1_rxfifoint_Level0,  /**< \brief  */
	qspi_globalcon1_rxfifoint_Level1,  /**< \brief  */
	qspi_globalcon1_rxfifoint_Level2,  /**< \brief  */
	qspi_globalcon1_rxfifoint_Level3,  /**< \brief  */
} qspi_globalcon1_rxfifoint;


/** \brief Receive FIFO Interrupt Threshold
 * Selects the first phase transition to trigger the PT interrupt
 * 000B BUSY (end of WAIT phase)
 * 001B SCLKPC (serial clock polarity change)
 * 010B SOF (Start of Frame)
 * 011B TBE (Transmit Buffer Emptied)
 * 100B RBF (Receive Buffer Filled)
 * 101B EOF (End of Frame)
 * 110B DNA (Data not Available = Start of Expect)
 * 111B CONT (End of EXPECT phase)
 */
typedef enum
{
	qspi_globalcon1_pt1_EndOfWaitPhase,  				/**< \brief  */
	qspi_globalcon1_pt1_SerialClockPolarityChange,  /**< \brief  */
	qspi_globalcon1_pt1_StartOfFrame,  					/**< \brief  */
	qspi_globalcon1_pt1_TransmitBufferEmptied,  /**< \brief  */
	qspi_globalcon1_pt1_ReceiveBufferFilled,  	/**< \brief  */
	qspi_globalcon1_pt1_EndOfFrame,  						/**< \brief  */
	qspi_globalcon1_pt1_DataNotAvailable,  			/**< \brief  */
	qspi_globalcon1_pt1_EndOfExpectPhase,  			/**< \brief  */
} qspi_globalcon1_pt1;

/** \brief Receive FIFO Interrupt Threshold
 * Selects the second phase transition to trigger the PT interrupt.
 * In master mode, the following events are available:
 * 000B BUSY (end of WAIT phase)
 * 001B SCLKPC (serial clock polarity change)
 * 010B SOF (Start of Frame)
 * 011B TBE (Transmit Buffer Emptied)
 * 100B RBF (Receive Buffer Filled)
 * 101B EOF (End of Frame)
 * 110B DNA (Data not Available = Start of Expect)
 * 111B CONT (End of EXPECT phase)
 * In slave mode, the SLSI deactivated event is the only option available
 * for PT2. For this purpose, always use the setting 101 (EOF).
 */
typedef enum
{
	qspi_globalcon1_pt2_EndOfWaitPhase,  				/**< \brief  */
	qspi_globalcon1_pt2_SerialClockPolarityChange,  /**< \brief  */
	qspi_globalcon1_pt2_StartOfFrame,  					/**< \brief  */
	qspi_globalcon1_pt2_TransmitBufferEmptied,  /**< \brief  */
	qspi_globalcon1_pt2_ReceiveBufferFilled,  	/**< \brief  */
	qspi_globalcon1_pt2_EndOfFrame,  						/**< \brief  */
	qspi_globalcon1_pt2_DataNotAvailable,  			/**< \brief  */
	qspi_globalcon1_pt2_EndOfExpectPhase,  			/**< \brief  */
} qspi_globalcon1_pt2;

/** \brief TXFIFO/RXFIFO Mode
 * Selects between the Single Move Mode and the Batch Move Mode.
 */
typedef enum
{
	qspi_globalcon1_txfm_CombinedMoveMode,  /**< \brief  */
	qspi_globalcon1_txfm_SingleMoveMode,  	/**< \brief  */
	qspi_globalcon1_txfm_BatchMoveMode,  		/**< \brief  */
} qspi_globalcon1_txfm;

/** \brief RXFIFO Mode
 * Selects between the Single Move Mode and the Batch Move Mode
 */
typedef enum
{
	qspi_globalcon1_rxfm_CombinedMoveMode, /**< \brief  */
	qspi_globalcon1_rxfm_SingleMoveMode,   /**< \brief  */
	qspi_globalcon1_rxfm_BatchMoveMode,  	 /**< \brief  */
} qspi_globalcon1_rxfm;

/**********BACONENTRY**************/

/** \brief Parity Type
 * Definition in
 */
typedef enum
{
	qspi_baconEntry_last_false,  /**< \brief  */
  qspi_baconEntry_last_true,     /**< \brief  */
} qspi_baconentry_last;

/** \brief User Interrupt at the PT1 Event in the Subsequent Frames
 * Definition in
 */
typedef enum
{
	qspi_baconEntry_partyp_Even,  /**< \brief  */
  qspi_baconEntry_partyp_Odd,   /**< \brief  */
} qspi_baconentry_partyp;

/** \brief
 * Definition in
 */
typedef enum
{
	qspi_baconEntry_UserInterruptPT1_EventDisabled,  /**< \brief  */
  qspi_baconEntry_UserInterruptPT1_EventEnabled,   /**< \brief  */
} qspi_baconentry_uint;

/** \brief Shift MSB or LSB First
 * Definition in
 */
typedef enum
{
	qspi_baconEntry_Shift_LSB_first,  /**< \brief  */
  qspi_baconEntry_Shift_MSB_first,  /**< \brief  */
} qspi_baconentry_msb;

/** \brief
 * Definition in
 */
typedef enum
{
	qspi_baconEntry_byte_Bits,     /**< \brief  */
  qspi_baconEntry_Byte_Bytes,    /**< \brief  */
} qspi_baconentry_byte;


/********ECON***************/

/** \brief Clock Phase
 * Definition in
 */
typedef enum
{
	qspi_econ_cph_0,    /**< \brief  */
  qspi_econ_cph_1,    /**< \brief  */
} qspi_econ_cph;

/** \brief Clock Polarity
 * Definition in
 */
typedef enum
{
	qspi_econ_cpol_0,  /**< \brief  */
  qspi_econ_cpol_1,  /**< \brief  */
} qspi_econ_cpol;


/** \brief Enable Parity Check
 * Definition in
 */
typedef enum
{
	qspi_econ_paren_Disabled, /**< \brief  */
  qspi_econ_paren_Enabled,  /**< \brief  */
} qspi_econ_paren;

/** \brief Permutate bytes to / from Big Endian
 * Definition in
 */
typedef enum
{
	qspi_econ_be_SwapDisabled, /**< \brief  */
	qspi_econ_be_Swap_16bit, /**< \brief  */
	qspi_econ_be_Swap_32bit, /**< \brief  */
} qspi_econ_be;

/********STATUS1*******************/

/** \brief Baud Rate Deviation Enable
 * Definition in
 */
typedef enum
{
	qspi_status1_BaudRateDeviationDisabled,   /**< \brief  */
  qspi_status1_BaudRateDeviationEnabled,   /**< \brief  */
} qspi_status1_brden;

/** \brief Baud Rate Deviation Flag
 * Definition in
 */
typedef enum
{
	qspi_status1_BaudRateDeviationNoEvent,   		/**< \brief  */
  qspi_status1_BaudRateDeviationEventDetected,/**< \brief  */
} qspi_status1_brd;

/** \brief Spike Detection Enable
 * Definition in
 */
typedef enum
{
	qspi_status1_SpikeDetectionDisabled,   /**< \brief  */
  qspi_status1_SpikeDetectionEnabled,   /**< \brief  */
} qspi_status1_spden;

/** \brief Spike Detection Flag
 * Definition in
 */
typedef enum
{
	qspi_status1_SpikeDetectionNoEvent,   /**< \brief  */
  qspi_status1_SpikeDetectionEventDetected,   /**< \brief  */
} qspi_status1_spd;

/**********SSOC*****************/

/** \brief
 * Definition in
 */
typedef enum
{
  qspi_ssoc_oen_none    = 0x0000,     /**< \brief  */
  qspi_ssoc_oen_slso0   = 0x0001,     /**< \brief  */
  qspi_ssoc_oen_slso1   = 0x0002,     /**< \brief  */
  qspi_ssoc_oen_slso2   = 0x0004,     /**< \brief  */
  qspi_ssoc_oen_slso3   = 0x0008,     /**< \brief  */
  qspi_ssoc_oen_slso4   = 0x0010,     /**< \brief  */
  qspi_ssoc_oen_slso5   = 0x0020,     /**< \brief  */
  qspi_ssoc_oen_slso6   = 0x0040,     /**< \brief  */
  qspi_ssoc_oen_slso7   = 0x0080,     /**< \brief  */
  qspi_ssoc_oen_slso8   = 0x0100,     /**< \brief  */
  qspi_ssoc_oen_slso9   = 0x0200,     /**< \brief  */
  qspi_ssoc_oen_slso10  = 0x0400,     /**< \brief  */
  qspi_ssoc_oen_slso11  = 0x0800,     /**< \brief  */
  qspi_ssoc_oen_slso12  = 0x1000,     /**< \brief  */
  qspi_ssoc_oen_slso13  = 0x2000,     /**< \brief  */
  qspi_ssoc_oen_slso14  = 0x4000,     /**< \brief  */
  qspi_ssoc_oen_slso15  = 0x8000,     /**< \brief  */
} qspi_ssoc_oen;

/** \brief
 * Definition in
 */
typedef enum
{
  qspi_ssoc_aol_none    = 0x0000,     /**< \brief  */
  qspi_ssoc_aol_slso0   = 0x0001,     /**< \brief  */
  qspi_ssoc_aol_slso1   = 0x0002,     /**< \brief  */
  qspi_ssoc_aol_slso2   = 0x0004,     /**< \brief  */
  qspi_ssoc_aol_slso3   = 0x0008,     /**< \brief  */
  qspi_ssoc_aol_slso4   = 0x0010,     /**< \brief  */
  qspi_ssoc_aol_slso5   = 0x0020,     /**< \brief  */
  qspi_ssoc_aol_slso6   = 0x0040,     /**< \brief  */
  qspi_ssoc_aol_slso7   = 0x0080,     /**< \brief  */
  qspi_ssoc_aol_slso8   = 0x0100,     /**< \brief  */
  qspi_ssoc_aol_slso9   = 0x0200,     /**< \brief  */
  qspi_ssoc_aol_slso10  = 0x0400,     /**< \brief  */
  qspi_ssoc_aol_slso11  = 0x0800,     /**< \brief  */
  qspi_ssoc_aol_slso12  = 0x1000,     /**< \brief  */
  qspi_ssoc_aol_slso13  = 0x2000,     /**< \brief  */
  qspi_ssoc_aol_slso14  = 0x4000,     /**< \brief  */
  qspi_ssoc_aol_slso15  = 0x8000,     /**< \brief  */
} qspi_ssoc_aol;

/**********PISEL*****************/

/** \brief
 * Definition in
 */
typedef enum
{
  qspi_pisel_mris_mrstxA,     /**< \brief  */
  qspi_pisel_mris_mrstxB,     /**< \brief  */
  qspi_pisel_mris_mrstxC,     /**< \brief  */
  qspi_pisel_mris_mrstxD,     /**< \brief  */
  qspi_pisel_mris_mrstxE,     /**< \brief  */
  qspi_pisel_mris_mrstxF,     /**< \brief  */
  qspi_pisel_mris_mrstxG,     /**< \brief  */
  qspi_pisel_mris_mrstxH,     /**< \brief  */
} qspi_pisel_mris;

/** \brief
 * Definition in
 */
typedef enum
{
  qspi_pisel_sris_mtsrxA,     /**< \brief  */
  qspi_pisel_sris_mtsrxB,     /**< \brief  */
  qspi_pisel_sris_mtsrxC,     /**< \brief  */
  qspi_pisel_sris_mtsrxD,     /**< \brief  */
  qspi_pisel_sris_mtsrxE,     /**< \brief  */
  qspi_pisel_sris_mtsrxF,     /**< \brief  */
  qspi_pisel_sris_mtsrxG,     /**< \brief  */
  qspi_pisel_sris_mtsrxH,     /**< \brief  */
} qspi_pisel_sris;

/** \brief
 * Definition in
 */
typedef enum
{
  qspi_pisel_scis_sclkxA,     /**< \brief  */
  qspi_pisel_scis_sclkxB,     /**< \brief  */
  qspi_pisel_scis_sclkxC,     /**< \brief  */
  qspi_pisel_scis_sclkxD,     /**< \brief  */
  qspi_pisel_scis_sclkxE,     /**< \brief  */
  qspi_pisel_scis_sclkxF,     /**< \brief  */
  qspi_pisel_scis_sclkxG,     /**< \brief  */
  qspi_pisel_scis_sclkxH,     /**< \brief  */
} qspi_pisel_scis;

/** \brief
 * Definition in
 */
typedef enum
{
  qspi_pisel_slsis_slsi_deselected,     /**< \brief  */
  qspi_pisel_slsis_slsixA,     /**< \brief  */
  qspi_pisel_slsis_mtsrxB,     /**< \brief  */
  qspi_pisel_slsis_mtsrxC,     /**< \brief  */
  qspi_pisel_slsis_mtsrxD,     /**< \brief  */
  qspi_pisel_slsis_mtsrxE,     /**< \brief  */
  qspi_pisel_slsis_mtsrxF,     /**< \brief  */
  qspi_pisel_slsis_mtsrxG,     /**< \brief  */
} qspi_pisel_slsis;
/** \} */

#endif	/* end of file */

